#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
Created on Fri Apr 05 18:08:04 2013

@author: John
"""
from scipy.optimize import fsolve
import numpy
import math

#returns in m
def Aeff(Dow,Diw,Hw):
 F = (Hw/Diw)*(math.sqrt(((Hw**2)/(Diw**2)+1.0))-Hw/Diw)
 aeff = 0.5*math.pi*(Dow**2-Diw**2)+math.pi*Hw*Dow+F*math.pi*Diw*Hw
 aeff = aeff * 10**-6 
 return aeff

def Avertical(Dow,Diw,Hw):
 base_area = 2*math.pi*(Dow/2+Diw/2)*Hw*10**-6
 area = base_area*math.pi/2  #taking into account size increase due to round wires 
 #print area
 return area

def Ahorizontal(Dow,Diw,Hw): 
 base_area = 2*math.pi*((Dow/2)**2-(Diw/2)**2)*10**-6
 area      = base_area*math.pi/2 #taking into account size increase due to round wires
 return area
 
def CoreSizeWithWindings(Core,Fillf):
 #print Fillf    
 deltaRnew= (Core[6]-math.sqrt(Core[6]**2*(1-Fillf)))/2  
 Dow = Core[5]+deltaRnew/2
 Diw = Core[6]-deltaRnew
 Hw = Core[7]+deltaRnew
 return [Dow,Diw,Hw]

def Calc_Area(Core,Mounting,Dow,Diw,Hw):
 aeff = Aeff(Dow,Diw,Hw)
 A_v = Avertical(Dow,Diw,Hw)
 A_h = Ahorizontal(Dow,Diw,Hw)
 A_f = 0#Forced
 return [A_v,A_h,A_f,aeff]
 
def Calc_L(Core,Mounting,Dow,Diw,Hw):
 L_v = Hw*10**-3
 L_h = (Dow/2-Diw/2)*10**-3
 L_f = 0#Forced conv 
 return [L_v,L_h,L_f]

def Rwind(alpha_w,Dow,Diw,Hw):
 CoreSurface = (2*math.pi*(Dow+Diw)*Hw+math.pi*(Dow**2+Diw**2))*10**-6   
 Rwind = 1/(alpha_w*CoreSurface)  
 return Rwind   

def ThermalPropertiesAir(Tamb,Ts):
 T = (Tamb+Ts)/2 #All parameters evaluated halfway to ambient
 #print Tamb ,Ts,T
 
 Density = 1.225*273.0/(T+258)
 Beta    = 1.0/(T+273) #Beta calculated betweem infinity and wall
 My      = 16.8*10**-6+52.0*10**-9.0*T #Viscosity
 Lamda   = 0.0242+6.2*10**-5.0*T
 Cp      = 1000.0
 v       = My/Density #Kinematic viscosity
 Pr      = Density*Cp*v/Lamda
 return [Density,Beta,My,Lamda,Cp,Pr,v] 

def P_Convection(Ta,Ts,L_v,L_h,A_v,A_h):
 g = 9.81 #Gravity 
 [Density,Beta,My,Lamda,Cp,Pr,v] = ThermalPropertiesAir(Ta,Ts)
 Power_v = (0.825+0.387*(L_v**3*g*Beta*(Ts[0]-Ta)*Pr/(v**2.0)*(1+(0.492/Pr)**(9.0/16.0))**(-16.0/9.0))**(1.0/6.0))**(2.0)*((Lamda*A_v/L_v)*(Ts-Ta))
 Power_h = (0.6+0.387*(L_h**3*g*Beta*(Ts[0]-Ta)*Pr/(v**2.0)*(1+(0.559/Pr)**(9.0/16.0))**(-16.0/9.0))**(1.0/6.0))**(2.0)*((Lamda*A_h/L_h)*(Ts-Ta)) 
 print Power_v,Power_h
 #print "alpha_v =", Power_v/(A_v*(Ts-Ta)),"alpha_h =", Power_h/(A_h*(Ts-Ta)),Ts
 return Power_v+Power_h
 
def P_raddiation(emissivity,aeff,Ts,Ta):
 Prad = 5.7*10**-8*emissivity*aeff*((Ts+273.15)**4-(Ta+273.15)**4)
 #print "Prad" ,Prad,aeff
 return Prad

def Solver(Ta,T_est,Powerloss,r_Sink,r_Wind,Velocity,emissivity,L_v,L_h,L_f,A_v,A_h,A_f,aeff):
 #print Ta,T_est,Powerloss,r_Sink,r_Wind,Velocity,emissivity,L_v,L_h,L_f,A_v,A_h,A_f,aeff
 Power =  lambda Ts: -Powerloss + P_Convection(Ta,Ts,L_v,L_h,A_v,A_h)+P_raddiation(emissivity,aeff,Ts,Ta)
 #Noe feil pga antar temp innenfor viklingene == utenfor
 Tcalc = fsolve(Power,Ta+T_est,maxfev=100)
 return Tcalc
 

def Calculate_T(Core,Ta,T_est,Powerloss,Velocity,alpha_w,R_sink,Fillf,N_Layers,emissivity,Mounting):
 [Dow,Diw,Hw] = CoreSizeWithWindings(Core,Fillf)  
 [A_v,A_h,A_f,aeff] = Calc_Area(Core,Mounting,Dow,Diw,Hw)
 [L_v,L_h,L_f] = Calc_L(Core,Mounting,Dow,Diw,Hw)
 r_Sink = R_sink  
 r_Wind = Rwind(alpha_w,Dow,Diw,Hw)
 
 Ts = Solver(Ta,T_est,Powerloss,r_Sink,r_Wind,Velocity,emissivity,L_v,L_h,L_f,A_v,A_h,A_f,aeff)   
 return Ts 
 
def Thermal_main(Core,Ta,surface,Powerloss,Velocity,FastThermal,R_sink,alpha_w,N_Layers,Fillf):
 emissivity = 0.58
 Mounting   = 1
 alpha_w    = 0.6
 #print "rember 10W hardcoded"#<<<<<<<<<<<<<<<
 #Calc Alpha_w 
 T_est = ((Powerloss*1000)/(surface*10000))**0.833 #Estimate for the temperature
 if(FastThermal==2):
  Power =  lambda Ts:  T_est-Ts
  Tcalc = fsolve(Power,Ta,maxfev=100)
  #print "Power loss",Powerloss,T_est,surface
  return Tcalc #this is in 'C

 else:    
  #print "Power loss",Powerloss,T_est,surface  
  T_calc = Calculate_T(Core,Ta,T_est,Powerloss,Velocity,alpha_w,R_sink,Fillf,N_Layers,emissivity,Mounting)    
  #print "Power loss",Powerloss,T_est,T_calc-Ta
  return T_calc-Ta   
#Problems
#print "problem with r_wind Tcalc 10x med denne. 
# feil temp over rwind
