#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
Created on Fri Apr 05 18:08:04 2013

@author: John
"""
import math
from scipy.optimize import fsolve
import math

#Dow outer diameter with cobber Diw inner diameter with cobber Hw height with cobber
def ThermalPropertiesAir(Tamb,Ts):
 T = ((Tamb+Ts)/2) #All parameters evaluated halfway to ambient
 Density = (1.225*273.0/((Tamb+Ts)/2))
 Beta    = (1.0/((Tamb+Ts)/2)) #Beta calculated betweem infinity and wall
 My      = (16.8*10**-6+52.0*10**-9.0*((Tamb+Ts)/2)) #Viscosity
 Lamda   = (0.0242+6.2*10**-5.0*((Tamb+Ts)/2))
 Cp      = 1000.0
 v       = My/Density #Kinematic viscosity         # (((16.8*10**-6+52.0*10**-9.0*((Ta+Ts)/2))/(1.225*273.0/((Ta+Ts)/2))))
 v2      = Lamda/(Density*Cp)#Thermal diffusity
 Pr      = Density*Cp*v/Lamda                      #((1.225*273.0/((Tamb+Ts)/2))*1000.0*((16.8*10**-6+52.0*10**-9.0*((Tamb+Ts)/2))/(1.225*273.0/((Tamb+Ts)/2)))/(0.0242+6.2*10**-5.0*((Tamb+Ts)/2)))
 return [Density,Beta,My,Lamda,Cp,Pr,v,v2] 

def ForcedConvection(w,L,v,Pr,Density):
 Re = w*L/v  #Comsol adds density here
 Ra = Re*Pr 
 print "Forced", w,L,v,Pr,"Re",Re  
 return Ra
 
def NaturalConvection(g,L,Beta,DeltaT,v,v2,Pr):
 #print "Ra Coeff", g,L,Beta,DeltaT,v,Pr 
 Gr    = L**(3.0)*g*Beta*DeltaT/(v*v2)
 Ra    = Gr*Pr
 #print "Ra this seems reasonable", Ra 
 return Ra

def Nu_v(Pr,Ra_na,Ra_fo):#Vertical Surfaces
 f1         = (1.0+(0.492/Pr)**(9.0/16.0))**(-16.0/9.0) #Vertical surfaces    
 Nu_na_v    = (0.825+0.387*(Ra_na*f1)**(1.0/6.0))**2.0 #Vertical surfaces natural convection
 Nu_fo_v    = 2* 0.3387*Pr**(1.0/3.0)*Ra_fo**(1.0/2.0)/(((1+(0.0468/Pr)**(2.0/3.0))**(1.0/4.0))) 
 return [Nu_na_v,Nu_fo_v]
 
def Nu_h_cylinders(Pr,Ra_na,Ra_fo):#Horizontal Cylinders
 print "Ra_fo",Ra_fo 
 f3         = (1.0+(0.559/Pr)**(9.0/16.0))**(-16.0/9.0)#Horizontal Cylinders
 Nu_na_h    = (0.6+0.387*(Ra_na*f3)**(1.0/6.0))**2.0#Horizontal Cylinders Natural convection
 Nu_fo_h    = 2* (0.3387*(Pr**(1.0/3.0))*Ra_fo**(1.0/2.0))/(((1+(0.0468/Pr)**(2.0/3.0))**(1.0/4.0)))
 return [Nu_na_h,Nu_fo_h]
 
def Pconvection(Ts,Tamb,Dow,Diw,Hw) :  
 DeltaT = Ts-Tamb 
 g      = 9.81 #gravity  
 L_v    = Hw*10**-3 #Characteristic height
 L_h    = (Dow/2-Diw/2)*10**-3 #Characteristic horizontal
 w      = 0.0     #m/s
 
 [Density,Beta,My,Lamda,Cp,Pr,v,v2] = ThermalPropertiesAir(Tamb,Ts)
########################################################################
#Vertical Surfaces
 Ra_na    = NaturalConvection(g,L_v,Beta,DeltaT,v,v2,Pr)
 Ra_fo    = ForcedConvection(w,L_v,v,Pr,Density) 
 
 
# print "Ra For_V",ForcedConvection(w,L_v,v,Pr),"Ra Nat_V",NaturalConvection(g,L_v,Beta,DeltaT,v,v2,Pr)
 [Nu_na_v,Nu_fo_v] = Nu_v(Pr,Ra_na,Ra_fo)
 #Nu_na_v = 0########################################################
 print "Nu_na_v",Nu_na_v,",Nu_fo_v",Nu_fo_v 
 Nu = (Nu_na_v**3+Nu_fo_v**3)**(1.0/3.0)
 #print "Nu_na",Nu_na_v ,"Nu_fo",Nu_fo_v,"Nu",Nu 

 alpha_v = Nu*Lamda/L_v #alpha is right
########################################################################
#Horizontal Surfaces
 Ra_na    = NaturalConvection(g,L_h,Beta,DeltaT,v,v2,Pr)
 Ra_fo    = ForcedConvection(w,L_h,v,Pr,Density) 
 print "Ra For_H",ForcedConvection(w,L_h,v,Pr,Density),"Ra Nat_H",NaturalConvection(g,L_h,Beta,DeltaT,v,v2,Pr)
 [Nu_na_h,Nu_fo_h] =  Nu_h_cylinders(Pr,Ra_na,Ra_fo)
 #Nu_na_h =0#############################################################
 print "Nu_na_h",Nu_na_h,",Nu_fo_h",Nu_fo_h
 Nu_h = (Nu_na_h**3+Nu_fo_h**3)**(1.0/3.0)
 print "Nu",Nu_h 
 alpha_h = Nu_h*Lamda/L_h
 ###########################
 #print "Empirical",(1/(10*(2*math.pi*(Dow/2+Diw/2)*Hw*10**-6+math.pi*((Dow/2)**2-(Diw/2)**2)*10**-6)))**(0.833)
 Pconv_v = 2*math.pi*(Dow/2+Diw/2)*Hw*10**-6*        alpha_v*(DeltaT)
 Pconv_h = 2*math.pi*((Dow/2)**2-(Diw/2)**2)*10**-6*   alpha_h*(DeltaT) 
 Pconv = Pconv_v+Pconv_h
 print "Pconv ",Pconv,"Pconv_v",Pconv_v,"Pconv_h",Pconv_h
 return Pconv

#returns in m
def Aeff(Dow,Diw,Hw):
 F = (Hw/Diw)*(math.sqrt(((Hw**2)/(Diw**2)+1.0))-Hw/Diw)
 aeff = 0.5*math.pi*(Dow**2-Diw**2)+math.pi*Hw*Dow+F*math.pi*Diw*Hw  
 return aeff

#Raddiated energy 
def Praddiated(emissivity,Ts,Ta,Dow,Diw,Hw):
 aeff = Aeff(Dow,Diw,Hw) # in mm^2
 #print aeff, 2*math.pi*(Dow/2+Diw/2)*Hw+math.pi*((Dow/2)**2-(Diw/2)**2)
 aeff = aeff*10**-6
 Pradd = 5.7*10**-8*emissivity*aeff*(Ts**4-Ta**4)
 return Pradd


def ThermalCalc(emissivity,Ts,Ta,Dow,Diw,Hw):
 Pradd   = Praddiated(emissivity,Ts,Ta,Dow,Diw,Hw)
 Pconvec = Pconvection(Ts,Ta,Dow,Diw,Hw) 
 Ptot = Pradd+Pconvec
 #Th_res_radd = (Ts-Ta)/Pradd
 print "Pradd",Pradd
 return Ptot
 
print ThermalCalc(0.5,293.15+90.9,293.15,51.7,30.9,14.4)


Power =  lambda Ts: -10+ThermalCalc(0.5,Ts,293.15,37.28,20.46,11.88)
Tcalc = fsolve(Power,300,maxfev=100) 
print "Fsolve power",Power,"Fsolve Tcalc", Tcalc-293.15
